@@ -125,9 +125,10 @@ class Test_Open_FilePicker(object):
         assert self.window.filename == u"example.txt"
 
     def test_subdirectory(self):
-        self.window.browse_folder(subdir=u"bar")
-        self.window.selection_directory()
+        index = self.window.dir_list_items.index(u'./bar')
+        self.window.onCellDoubleClicked(index, 0)
         QtWidgets.QApplication.processEvents()
+        assert self.window.file_list_items[0] == "./bar/foo.txt"
         self.window.onCellClicked(0, 0)
         QtWidgets.QApplication.processEvents()
         self.window.action()
@@ -233,3 +234,22 @@ class Test_Save_FilePicker(object):
         QtWidgets.QApplication.processEvents()
         self.window.close()
         assert u'./empty/exampledir' in self.window.dir_list_items
+
+    @mock.patch("fslib.fs_filepicker.QtWidgets.QInputDialog.getText",
+                return_value=(u"thisexampledir", True))
+    def test_history_makedir(self, mocktext):
+        index = self.window.dir_list_items.index(u'./empty')
+        self.window.onCellDoubleClicked(index, 0)
+        QtWidgets.QApplication.processEvents()
+        self.window.history_previous()
+        index = self.window.dir_list_items.index(u'./bar')
+        self.window.onCellDoubleClicked(index, 0)
+        QtWidgets.QApplication.processEvents()
+        self.window.history_previous()
+        assert self.window.ui_DirList.currentText() == './empty'
+        QtWidgets.QApplication.processEvents()
+        self.window.make_dir()
+        QtWidgets.QApplication.processEvents()
+        self.window.close()
+        assert u'./empty/thisexampledir' in self.window.dir_list_items
+        assert self.window.last_dir_index == 1
