@@ -50,7 +50,7 @@ def match_extension(name, extensions=None):
 
 def root_url():
     if sys.platform.startswith('win'):
-        return u"c://"
+        return u"file:///"
     else:
         return u"/"
 
@@ -88,4 +88,3 @@ class WidgetImageText(QWidget):
     @pyqtProperty(str)
     def value(self):
         return self._value
-
